@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::JSON::Schema::Acceptance; # git description: v1.003-3-g266ec84
+package Test::JSON::Schema::Acceptance; # git description: v1.004-2-g150a61e
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Acceptance testing for JSON-Schema based validators like JSON::Schema
 
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 
 use 5.014;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -27,7 +27,7 @@ has specification => (
   is => 'ro',
   isa => Str,
   lazy => 1,
-  default => 'draft2019-09',
+  default => 'draft2020-12',
   predicate => '_has_specification',
 );
 
@@ -79,7 +79,7 @@ has results => (
 around BUILDARGS => sub {
   my ($orig, $class, @args) = @_;
   my %args = @args % 2 ? ( specification => 'draft'.$args[0] ) : @args;
-  $args{specification} = 'draft2019-09' if ($args{specification} // '') eq 'latest';
+  $args{specification} = 'draft2020-12' if ($args{specification} // '') eq 'latest';
   $class->$orig(\%args);
 };
 
@@ -347,7 +347,7 @@ Test::JSON::Schema::Acceptance - Acceptance testing for JSON-Schema based valida
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -384,8 +384,8 @@ cases in the JSON Schema Test Suite, except for those listed in C<$skip_tests>.
 L<JSON Schema|http://json-schema.org> is an IETF draft (at time of writing) which allows you to
 define the structure of JSON.
 
-From the overview of the L<draft 2019-09 version of the
-specification|https://json-schema.org/draft/2019-09/json-schema-core.html#rfc.section.3>:
+From the overview of the L<draft 2020-12 version of the
+specification|https://json-schema.org/draft/2020-12/json-schema-core.html#rfc.section.3>:
 
 =over 4
 
@@ -445,7 +445,11 @@ C<draft2019-09>
 
 =item *
 
-C<latest> (alias for C<draft2019-09>)
+C<draft2020-12>
+
+=item *
+
+C<latest> (alias for C<draft2020-12>)
 
 =back
 
@@ -527,7 +531,7 @@ associated with that URI, for use in some tests that use additional resources (s
 not provide this option, you will be responsible for ensuring that those additional resources are
 made available to your implementation for the successful execution of the tests that rely on them.
 
-For more information, see <https://json-schema.org/draft/2019-09/json-schema-core.html#rfc.section.8.2.4.5>.
+For more information, see <https://json-schema.org/draft/2020-12/json-schema-core.html#rfc.section.9.1.2>.
 
 =head3 tests
 
